require 'thor'
require 'thor/group'

module Rocketwheel
  module Command
    module CLI
      class Base < Thor
        class << self
          def start(*args)
            # Change flag to a module
            ARGV.unshift('help') if ARGV.delete('--help')

            super
          end

          def filename
            Rocketwheel::Command::MANIFEST
          end
        end

        desc 'version', 'Show version'
        def version
          require 'rocketwheel/command/version'
          say "Rocketwheel Command #{Rocketwheel::Command::VERSION}"
        end

        # Override the Thor help method to find help for subtasks
        # @param [Symbol, String, nil] meth
        # @param [Boolean] subcommand
        # @return [void]
        def help(meth = nil, subcommand = false)
          if meth && !self.respond_to?(meth)
            klass, task = Thor::Util.find_class_and_task_by_namespace("#{meth}:#{meth}")
            klass.start(["-h", task].compact, :shell => self.shell)
          else
            list = []
            Thor::Util.thor_classes_in(Rocketwheel::Command::CLI).each do |klass|
              list += klass.printable_tasks(false)
            end
            list.sort!{ |a,b| a[0] <=> b[0] }

            shell.say "Tasks:"
            shell.print_table(list, :ident => 2, :truncate => true)
            shell.say
          end
        end

        # Intercept missing methods and search subtasks for them
        # @param [Symbol] meth
        def method_missing(meth, *args)
          meth = meth.to_s

          if self.class.map.has_key?(meth)
            meth = self.class.map[meth]
          end

          klass, task = Thor::Util.find_class_and_task_by_namespace("#{meth}:#{meth}")

          if klass.nil?
            tasks_dir = File.join(Dir.pwd, "tasks")

            if File.exists?(tasks_dir)
              Dir[File.join(tasks_dir, "**/*_task.rb")].each { |f| require f }
              klass, task = Thor::Util.find_class_and_task_by_namespace("#{meth}:#{meth}")
            end
          end

          if klass.nil?
            raise Thor::Error.new "There's no '#{meth}' command. Try 'rocket help' for a list of commands."
          else
            args.unshift(task) if task
            klass.start(args, :shell => self.shell)
          end
        end

      protected

        def manifest
          @manifest ||= begin 
            file = File.join(File.expand_path('./'), self.class.filename)
            raise Thor::Error, "No #{self.class.filename} file found" unless File.exists?(file)
            Manifest.from_file(file)
          end
        end

      end
    end
  end
end

require 'rocketwheel/command/cli/versions'
require 'rocketwheel/command/cli/new'
require 'rocketwheel/command/cli/build'
require 'rocketwheel/command/cli/encode'
require 'rocketwheel/command/cli/deploy'
