module Rocketwheel::Command::CLI
  class Build < Base
    include Thor::Actions

    namespace :build

    def self.source_root
      File.expand_path("./")
    end

    desc 'build', 'Build the source files into a deployable package.'
    method_option :source,
      :aliases => '-s',
      :desc => 'Source directory to build from.',
      :default => 'source'
    method_option :destination,
      :aliases => '-d',
      :desc => 'Directory to store the build.',
      :default => 'build'
    def build
      directory source, destination
      say_status :downloading, 'demoplayer'
      player.download_and_unzip(File.join(destination, 'demoplayer'))
    rescue Rocketwheel::Command::PlayerNotFound => e
      raise Thor::Error, "#{e.message} Run `rocket versions` to see a full list of available players."
    end

    no_tasks do
      def player_options_480
        manifest.player_options_480
      end

      def player_options_720
        manifest.player_options_720
      end

      def playlist
        manifest.playlist
      end

      def meta
        manifest.meta
      end

    end

  private

    def player
      Rocketwheel::Command::Player.version(version)
    end

    def version
      manifest.version
    end

    def source
      options[:source]
    end

    def destination
      options[:destination]
    end

  end
end
