require 'fog'
require 'mime/types'

module Rocketwheel::Command::CLI
  class Deploy < Base
    include Thor::Actions

    namespace :deploy

    desc 'deploy', 'Push a directory to s3.'
    method_option :dir,
      :aliases => '-d',
      :desc => 'Build directory to deploy.',
      :default => 'build'
    def deploy
      invoke Task, [directory, config]
    end

    class Task < Thor::Group
      argument :source
      argument :config

      def upload
        files_to_upload.each do |file|
          upload_file(file) if File.file?(file)
        end
      end

    private

      def upload_file(file)
        key = File.join(prefix, file.sub(/#{source}\/?/, ''))
        mime = MIME::Types.type_for(file).first
        say_status :uploading, key, :green
        bucket.files.create(
          :key => key,
          :body => File.read(file),
          :public => true,
          :content_type => mime
        )
      end

      def bucket
        @bucket ||= s3.directories.get(bucket_name, :prefix => prefix)
      end

      def s3
        @s3 ||= Fog::Storage.new(
          :provider => 'AWS',
          :aws_access_key_id => aws_key,
          :aws_secret_access_key => aws_secret
        )
      end

      def files_to_upload
        Dir["#{source}/**/**"]
      end

      def aws_key
        config.key
      end

      def aws_secret
        config.secret
      end

      def bucket_name
        config.bucket
      end

      def prefix
        config.path
      end

    end

  private

    def directory
      File.join(File.expand_path('./'), dir)
    end

    def dir
      options[:dir]
    end

    def config
      manifest.s3
    end

  end
end
