require 'rocketwheel/command/encoder'

module Rocketwheel::Command::CLI
  class Encode < Base
    include Thor::Actions

    namespace :encode

    desc 'encode', 'Encode videos using transloadit.'
    method_option :source,
      :aliases => '-s',
      :desc => 'Directory where the unencoded videos are stored.',
      :default => 'source/videos'
    method_option :destination,
      :aliases => '-d',
      :desc => 'Directory where the encoded videos will be stored.',
      :default => 'build/videos'
    def encode
      files = Dir["#{File.join(File.expand_path('./'), source)}/**/**"].select { |f| File.file?(f) }
      invoke Task, [files, manifest, File.join(File.expand_path('./'), destination)]
    end

    class Task < Thor::Group
      argument :files
      argument :manifest
      argument :destination

      def encode
        files.each do |file|
          say_status :encoding, File.basename(file)
        end
        @encoder = Rocketwheel::Command::Encoder.new(manifest)
        encoder.encode(files)
      end

      def wait
        until encoder.encoded? do sleep 2; end
      end

      def download
        encoder.store(destination) do |result|
          say_status :downloading, result['name']
        end
      end

    private

      def encoder
        @encoder
      end

    end

  private

    def source
      options[:source]
    end

    def destination
      options[:destination]
    end

  end
end
