require 'fileutils'

module Rocketwheel::Command::CLI
  class New < Thor
    include Thor::Actions

    namespace :new

    def self.source_root
      File.join(Rocketwheel::Command.templates, 'project')
    end

    desc 'new [name]', 'Start a new project.'
    method_option :version,
      :desc => 'The player version to use. Defaults to latest.'
    def new(name)
      dir = version.dup
      until File.exists?(File.join(self.class.source_root, dir)) do
        raise Thor::Error, "No project template for version #{version}" unless dir.gsub! /(.*)\..*/, '\\1'
      end
      directory dir, name
    end

    no_tasks do
      def version
        options[:version] || Rocketwheel::Command::Player.latest_version
      end
    end

    class NoTemplateDirectory < Directory
    protected

      def execute!
        lookup = Thor::Util.escape_globs(source)
        lookup = config[:recursive] ? File.join(lookup, '**') : lookup
        lookup = file_level_lookup(lookup)

        files(lookup).sort.each do |file_source|
          next if File.directory?(file_source)
          next if config[:exclude_pattern] && file_source.match(config[:exclude_pattern])
          file_destination = File.join(given_destination, file_source.gsub(source, '.'))
          file_destination.gsub!('/./', '/')

          case file_source
          when /\.empty_directory$/
            dirname = File.dirname(file_destination).gsub(/\/\.$/, '')
            next if dirname == given_destination
            base.empty_directory(dirname, config)
          when /\.ignore$/
            destination = base.copy_file(file_source, file_destination[0..-8], config, &@block)
          when /\.tt$/
            destination = base.template(file_source, file_destination[0..-4], config, &@block)
          else
            destination = base.copy_file(file_source, file_destination, config, &@block)
          end
        end
      end
    end

  private

    def directory(source, *args, &block)
      config = args.last.is_a?(Hash) ? args.pop : {}
      destination = args.first || source
      action NoTemplateDirectory.new(self, source, destination || source, config, &block)
    end

  end
end
