require 'transloadit'
require 'open-uri'
require 'fileutils'
require 'net/http'

module Rocketwheel
  module Command
    class Encoder
      def initialize(manifest)
        @manifest = manifest
      end

      # Public: Starts an encoding job, sending the files to transloadit.
      def encode(files)
        files = files.map { |file| open(file) }
        @response = transloadit.assembly(assembly).submit! *files
      end

      def encoded?
        response.reload!
        response.completed?
      end

      def store(destination)
        response['results'].each do |name, result|
          result.each do |result|
            yield result if block_given?
            folder = File.join(destination, name)
            FileUtils.mkdir_p(folder)
            filename = File.join(folder, result['name'])
            download(result['url'], filename)
          end
        end
      end

    private
      attr_accessor :root, :manifest, :response

      def download(url, destination)
        uri = URI.parse(url)
        Net::HTTP.start(uri.host) do |http|
          resp = http.get(uri.path)
          File.open(destination, 'wb') { |f| f.write(resp.body) }
        end
      end

      def transloadit
        @transloadit ||= Transloadit.new(
          :key => transloadit_config.key,
          :secret => transloadit_config.secret
        )
      end

      def transloadit_config
        manifest.transloadit
      end

      def default_steps
        YAML.load(File.read(File.join(Rocketwheel::Command.templates, 'transloadit.yml')))['steps']
      end

      def custom_steps
        transloadit_config.steps
      end

      def assembly
        { 'steps' => custom_steps || default_steps }
      end

    end
  end
end
