require 'thor/core_ext/hash_with_indifferent_access'
require 'yaml'

module Rocketwheel
  module Command
    class Manifest < Thor::CoreExt::HashWithIndifferentAccess
      S3Config = Struct.new(:key, :secret, :bucket, :path)
      TransloaditConfig = Struct.new(:key, :secret, :steps)

      def self.from_file(path)
        new(YAML.load(File.open(path)))
      end

      def version
        @version ||= self.fetch('version', Player.latest_version)
      end

      def s3
        @s3 ||= begin
          config = self.fetch('s3', Hash.new)
          S3Config.new(config['key'], config['secret'], config['bucket'], config['path'].to_s)
        end
      end

      def playlist
        @playlist = self.fetch('playlist', [])
      end

      def player_options_480
        @player_options_480 ||= self.fetch('player-480', Hash.new)
      end

      def player_options_720
        @player_options_720 ||= self.fetch('player-720', Hash.new)
      end

      def meta
        @meta ||= self.fetch('meta', Hash.new)
      end

      def transloadit
        @transloadit ||= begin
          config = self.fetch('transloadit', Hash.new)
          TransloaditConfig.new(config['key'], config['secret'], config['steps'])
        end
      end

    end
  end
end
