require 'open-uri'
require 'net/http'
require 'zip/zip'
require 'fileutils'

module Rocketwheel
  module Command
    PlayerNotFound = Class.new(StandardError)

    class Player
      HOST = 'https://demoplayers.s3.amazonaws.com'

      attr_reader :json

      def initialize(json)
        @json = json
      end

      def version
        json['version']
      end

      def download_url
        json['download']
      end

      def download_and_unzip(destination)
        file = open(download_url)
        Zip::ZipFile::open(file) do |zf|
          zf.each do |e|
            path = File.join(destination, e.to_s)
            FileUtils.mkdir_p(File.dirname(path))
            zf.extract(e, path) { true }
          end
        end
      end

      class << self
        def json
          @json ||= JSON.parse(open(File.join(HOST, 'versions.json')).read)
        end

        def all
          versions.map { |p| self.new(p) }
        end

        def latest_version
          json['latest']
        end

        def latest
          version(latest_version)
        end

        def version(version)
          all.find { |player| player.version.to_s == version.to_s } || raise(PlayerNotFound, "Version #{version} of the player was not found.")
        end

        def versions
          json['versions']
        end
      end
    end
  end
end
