# Deployment Guide
The Luminosity Player has been configured and placed into the **index-480.html** and **index-720.html**
files that sit at the root of your deployment package. It is ready for you to
deploy to your server.

Below is an outline of the deployment code present in the **index-480.html** file.
Please note that in order for the player to function the folder structure must
remain intact. If you do move files out of this structure you will need to alter file paths. **Some basic HTML skills will be required to complete the deployment.**

## Meta Tags
The og(open graph) meta tags are used by the 'Share This' widget. Use these tags to define the information that 'Share This' shares. For more documentation see: http://support.sharethis.com/customer/portal/articles/475079-share-properties-and-sharing-custom-information#Open_Graph_Tags

You will need to add an absolute URL for **og:image** tag. This should point to the poster thumb image that lives in the images folder on your server. 

Also please change the **og:url** tag with the URL of the page that the video resides in. If your are pulling the video into the page via an iFrame, please use the Parent Page URL.

```
  <meta property="og:title" content="Cybertap Recon" />
  <meta property="og:type" content="Sharing Widgets" />
  <meta property="og:url" content="http://www.cybertapllc.com/" />
  <meta property="og:image" content="images/cyb-ux-preview.png" />
  <meta property="og:description" content="Cybertab Recon Overview Video" />
  <meta property="og:site_name" content="cybertapllc.com" />
```

The viewport meta tag is used by mobile devices to size the video page. 

```
    <meta name="viewport" content="width=880" />
```


## CSS Includes
The following CSS stylesheet provides styling for the player.
```
  <link rel="stylesheet" href="demoplayer/stylesheets/player.css" type="text/css" media="screen">
```
## JavaScript Includes
The following script should be included.

```
  <script src="demoplayer/javascripts/player.js" type="text/javascript"></script>
```




## Google Analytics & Player Initialization
The main inline JavaScript section that appears in the <head> section of the webpage includes Google Analytics Setup, Tracking Vars, Playlists, Player Options and Event Tracking. The only item you may need to change is the Google Analytics Account ID. Everything else should stay as is.


### Google Analytics
The first section of JavaScript code is standard Google Analytics embed code. 

We've already added your Googel Analytics Account ID... you're good to go!

You can add your Google Analytics Account ID to this code by replacing the 'UA-xxxxxxx-x' string with your account ID. If you do not use Google Analytics, leave it as is. 

```
  //google analytics
  var _gaq = _gaq || [];
  _gaq.push(['_setAccount', 'UA-xxxxxxx-x']);
  _gaq.push(['_trackPageview']);
  (function() {
  var ga = document.createElement('script'); ga.type = 'text/javascript'; ga.async = true;
  ga.src = ('https:' == document.location.protocol ? 'https://ssl' : 'http://www') + '.google-analytics.com/ga.js';
  var s = document.getElementsByTagName('script')[0]; s.parentNode.insertBefore(ga, s);
  })();
```

### Tracking Vars
Next are a set of tracking varibles, no need to do anything here, we've set these up already.
```
  //tracking vars
  var track_category = "Cybertab - Recon Overview";
  var percentage_played = 0;
  var secs_played =  0;
  var track_play = true; 
  var title = null;
  var this_duration = 0;
  var video_completed = true;
  var ctaLink = null;
```

### Player Setup
The demo player and its playlist is then initiated by the following lines of JavaScript. In this section you initiate the player, build out the playlist(s) by defining the duration of the movie, location of the poster thumb, title, description and video file. 

Additionally you can set the video to autostart by changing its value to 'true'.

Again please note if you move the location of assets such as images and video files out of the folder structure provided, you will need to update the playlist file paths that link to these assets. 

```
  $(function() {
    Player.setup({
      playlist: [
      {
        "image": "images/cyb-ux-preview.png",
        "title": "Cybertap Recon",
        "description": "Description",
        "duration": 190,
        "levels": [
          {
            "file": "videos/cyb-ux-final.mp4"
          }
        ]
      }
    ],
      jwplayer_options: {
        autostart: false,
        width: 854,
        height: 480 
      }
    })
```

### Events and Tracking
The following code triggers Google Analytics Event Tracking.
```
  //Events and Tracking
  Player.addHandler('onPlay', function() {
      if(track_play) {
          title = Player.Controller.playlist[Player.Controller.current.index].title;
          this_duration = Player.Controller.playlist[Player.Controller.current.index].duration;
          track_play = false;
          video_completed = false;
          _gaq.push(['_trackEvent', track_category, 'Video: Started', title]);
      };
  });
  Player.addHandler('onComplete', function(e) {
      video_completed = true;
      track_play = true;
      _gaq.push(['_trackEvent', track_category, 'Video: Completed', title]);
      _gaq.push(['_trackEvent', track_category, 'Video: Seconds Played', title, this_duration]);
      _gaq.push(['_trackEvent', track_category, 'Video: Percentage Played', title, 100]);
  });
  Player.addHandler('onPlaylistItem', function(e) {
      if(!video_completed) {
          _gaq.push(['_trackEvent', track_category, 'Video: Seconds Played', title, secs_played]);
          _gaq.push(['_trackEvent', track_category, 'Video: Percentage Played', title, percentage_played]);
      }
      track_play = true;
  });
  Player.addHandler('onTime', function(e) {
      secs_played =  Math.round(e.position);
      percentage_played = Math.round((secs_played / this_duration) * 100);
  });
  $('.track-link').live("click", function(event){
      event.preventDefault();
      _gaq.push(['_trackEvent', track_category, $(this).data('track-action') , Player.Controller.playlist[Player.Controller.current.index].title]);
      ctaLink = $(this).attr('href');
      setTimeout(function() {
          top.location.href = ctaLink;
      }, 1500);
  });
  window.onbeforeunload = function(e) {
      if(!video_completed) {
          _gaq.push(['_trackEvent', track_category, 'Video: Percentage Played', title, percentage_played]);
          _gaq.push(['_trackEvent', track_category, 'Video: Seconds Played', title, secs_played]);
      }
  };
  //end of Events and Tracking
```



## Player HTML Markup
The following markup is placed into the body of the web page. When the player
initiates, it will be loaded into this markup. Share This button html hooks are defined inside the player branding div. Call To Action links are defined inside the annotation tags. To change the URL destinations, simply change the anchor href properties. 

```
  <div id="demoplayer-position">
    <script type="text/x-handlebars">
      {{#view Player.View styles="inline"}}
        {{view Player.PlayerView}}
          <div id="demoplayer-branding">
              <img src="images/cyb-logo.png" />
              <div class="share">
                <span  class='st_linkedin_large' ></span>
                <span  class='st_twitter_large' ></span>
                <span  class='st_facebook_large' ></span>
                <span  class='st_email_large' ></span>
                <span  class='st_sharethis_large' ></span>
              </div>
          </div>
      {{/view}}           
    </script>
    <script type="text/x-handlebars" data-template-name="annotations">
            {{#annotation cta-1 video="1" start="189" image="images/cyb-ux-cta-480.png"}}
                <div class="demoplayer-action-playfirst">
                    <a href="#" id="replay"><img src="demoplayer/images/replay.png" /></a>
                </div>     
            {{/annotation}}   
    </script>
  </div>
```


## Share This JavaScript Includes
Lastly the following code sets up the share this button functionality. If you have a ShareThis account, you can replace the generic publisher ID in the code with your publisher ID. 
```
  <script type="text/javascript">var switchTo5x=true;</script>
  <script type="text/javascript" src="http://w.sharethis.com/button/buttons.js"></script>
  <script type="text/javascript">
    stLight.options({
            // replace this generic publisher ID with your own. If you do not have an account, leave as is.
            publisher:'b9f8cca1-6dd1-42d9-b354-0ae0088e96cc',
            onhover:false
    });
  </script>
```